@@ -291,6 +291,7 @@ _SPIRV_OP(ImageSparseTexelsResident, 316)
 _SPIRV_OP(NoLine, 317)
 _SPIRV_OP(AtomicFlagTestAndSet, 318)
 _SPIRV_OP(AtomicFlagClear, 319)
+_SPIRV_OP(SizeOf, 321)
 _SPIRV_OP(TypePipeStorage, 322)
 _SPIRV_OP(ConstantPipeStorage, 323)
 _SPIRV_OP(CreatePipeFromPipeStorage, 324)
@@ -365,6 +366,8 @@ _SPIRV_OP(AtomicFMinEXT, 5614)
 _SPIRV_OP(AtomicFMaxEXT, 5615)
 _SPIRV_OP(AssumeTrueKHR, 5630)
 _SPIRV_OP(ExpectKHR, 5631)
+_SPIRV_OP(DecorateString, 5632)
+_SPIRV_OP(MemberDecorateString, 5633)
 _SPIRV_OP(VmeImageINTEL, 5699)
 _SPIRV_OP(TypeVmeImageINTEL, 5700)
 _SPIRV_OP(TypeAvcImePayloadINTEL, 5701)
